"""This is my first python"""
def print_lol(the_list) :
    for each_item in the_list :
        if isinstance(each_item, list) :
            print_lol(each_item)
        else :
            print(each_item)




from distutils.core import setup

setup(
    name = 'su_nester',
    version = '1.0.0',
    py_modules = ['nester'],
    author = 'sujunyi',
    author_email = 'sujunyi_test@163.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested list',
)
